## extract ppt from a video

### useage
``` shell
# help info
evp --help
# example
evp --degree 0.6 --pdfname yeah.pdf ./ ./test.mp4
# degree: if frame is same with last frame over degree , this frame will be dropped
# pdfname: the name for export pdf 
```